@@ -3,5 +3,5 @@
 """Top-level package for Airflow Prometheus Exporter."""
 
 __author__ = """Robinhood Markets, Inc."""
-__email__ = 'open-source@robinhood.com'
-__version__ = '1.0.1'
+__email__ = "open-source@robinhood.com"
+__version__ = "__version__ = '1.0.8'"
